--Globals
local pairs = pairs

-- Isolate the environment
local folder, core = ...
setfenv(1, core)
-- local

CoreOptionsTable = {
	name = titleFull,
	type = "group",
	childGroups = "tab",

	args = {
		core={
			name = L["Core"],
			type = "group",
			order = 1,
			args={}
		},
		avr={
			name = L["AVR"],
			type = "group",
			order = 3,
			args={
				what = {
					type = "description",	order = 1,
					name = L["The addon Augmented Virtual Reality is needed to display 3D rings around totems.\nDownload it from curse.com, wowace.com or wowinterface.com"],
					width = "full",
				}
			},
		},
	},
}



CoreOptionsTable.args.core.args.enable = {
	type = "toggle",	order	= 1,
	name	= L["Enable"],
	desc	= L["Enables / Disables the addon"],
	set = function(info,val) 
		if val == true then
			core:Enable()
		else
			core:Disable()
		end
	end,
	get = function(info) return core:IsEnabled() end
}

defaultSettings.profile.trackOthersTotems = true
CoreOptionsTable.args.core.args.trackOthersTotems = {
	type = "toggle",	order	= 2,
	name	= L["Track other's totems"],
	desc	= L["Add other shaman's totems to your minimap."],
	set = function(info,val) 
		P.trackOthersTotems = val
	end,
	get = function(info) return P.trackOthersTotems end
}

defaultSettings.profile.broadcastTotemLocation = true
CoreOptionsTable.args.core.args.broadcastTotemLocation = {
	type = "toggle",	order	= 3,
	name	= L["Broadcast totem location"],
	desc	= L["Broadcast your totem's location to group members."],
	set = function(info,val) 
		P.broadcastTotemLocation = val
	end,
	get = function(info) return P.broadcastTotemLocation end
}

defaultSettings.profile.colourRingBySchool = true
CoreOptionsTable.args.core.args.colourRingBySchool = {
	type = "toggle",	order	= 4,
	name	= L["Colour ring by school"],
	desc	= L["Colour the rings on minimap by totem school instead of range"],
	set = function(info,val) 
		P.colourRingBySchool = val
		
		if val == true then
			local totemSlot
			for totemGUID, data in pairs(activeTotems) do 
				totemSlot = data.totemSlot
				data.icon.outlineTexture:SetVertexColor(P.totemColour[totemSlot].r, P.totemColour[totemSlot].g, P.totemColour[totemSlot].b, P.totemColour[totemSlot].a)
			end
--~ 			CoreOptionsTable.args.core.args.insideRingColour.disabled = true
--~ 			CoreOptionsTable.args.core.args.outsideRingColour.disabled = true
		else
--~ 			CoreOptionsTable.args.core.args.insideRingColour.disabled = false
--~ 			CoreOptionsTable.args.core.args.outsideRingColour.disabled = false
		end
		
	end,
	get = function(info) return P.colourRingBySchool end
}

defaultSettings.profile.totemColour[1]	= {r=1, g=0, b=0} --red
CoreOptionsTable.args.core.args.fireColour = {
	name = L["Fire Colour"],	order	= 10,
	desc = L["Colour of the circle around the totem"],
	type = "color",
--~ 	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[1].r = r
		P.totemColour[1].g = g
		P.totemColour[1].b = b
--~ 		P.totemColour[1].a = a
		
--~ 		for GUID, data in pairs(activeTotems) do 
--~ 			if data.totemSlot == 1 then
--~ 				data.icon.solidTexture:SetVertexColor(r, g, b, a);
--~ 			end
--~ 		end
--~ 		print(Round(r,2), Round(g,2), Round(b,2), Round(a,2))
	end,
	get = function(info) return P.totemColour[1].r, P.totemColour[1].g, P.totemColour[1].b, P.totemColour[1].a end
}

defaultSettings.profile.totemColour[2]	= {r=0, g=1, b=0} --green
CoreOptionsTable.args.core.args.earthColour = {
	name = L["Earth Colour"],	order	= 11,
	desc = L["Colour of the circle around the totem"],
	type = "color",
--~ 	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[2].r = r
		P.totemColour[2].g = g
		P.totemColour[2].b = b
--~ 		P.totemColour[2].a = a
		
--~ 		for GUID, data in pairs(activeTotems) do 
--~ 			if data.totemSlot == 2 then
--~ 				data.icon.solidTexture:SetVertexColor(r, g, b, a);
--~ 			end
--~ 		end
	end,
	get = function(info) return P.totemColour[2].r, P.totemColour[2].g, P.totemColour[2].b, P.totemColour[2].a end
}

defaultSettings.profile.totemColour[3]	= {r=0, g=0.5, b=1} --cyan
CoreOptionsTable.args.core.args.waterColour = {
	name = L["Water Colour"],	order	= 12,
	desc = L["Colour of the circle around the totem"],
	type = "color",
--~ 	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[3].r = r
		P.totemColour[3].g = g
		P.totemColour[3].b = b
		P.totemColour[3].a = a
		
--~ 		for GUID, data in pairs(activeTotems) do 
--~ 			if data.totemSlot == 3 then
--~ 				data.icon.solidTexture:SetVertexColor(r, g, b, a);
--~ 			end
--~ 		end
	end,
	get = function(info) return P.totemColour[3].r, P.totemColour[3].g, P.totemColour[3].b, P.totemColour[3].a end
}

defaultSettings.profile.totemColour[4]	= {r=1, g=1, b=1} --white
CoreOptionsTable.args.core.args.airColour = {
	name = L["Air Colour"],	order	= 13,
	desc = L["Colour of the circle around the totem"],
	type = "color",
--~ 	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[4].r = r
		P.totemColour[4].g = g
		P.totemColour[4].b = b
--~ 		P.totemColour[4].a = a
		
--~ 		for GUID, data in pairs(activeTotems) do 
--~ 			if data.totemSlot == 4 then
--~ 				data.icon.solidTexture:SetVertexColor(r, g, b, a);
--~ 			end
--~ 		end
	end,
	get = function(info) return P.totemColour[4].r, P.totemColour[4].g, P.totemColour[4].b, P.totemColour[4].a end
}

defaultSettings.profile.minimapIconRange = 200
CoreOptionsTable.args.core.args.minimapIconRange = {
	type	= "range",	order	= 16,
	name = L["Minimap Show Range"],
	desc = L["Hide the icon if we're beyond * yards away."],
	min		= 50,
	max		= 200,
	step	= 5,
	set = function(info,val) 
		P.minimapIconRange = val;
	end,
	get = function(info) return P.minimapIconRange end
}

defaultSettings.profile.iconSize = 12
CoreOptionsTable.args.core.args.iconSize = {
	type	= "range",	order	= 17,
	name = L["Icon Size"],
	desc = L["Size of the totem icon on the minimap. (Not the circle)"],
	min		= 4,
	max		= 32,
	step	= 4,
	set = function(info,val) 
		P.iconSize = val;
		
		for GUID, data in pairs(activeTotems) do 
			data.icon:SetWidth(val)
			data.icon:SetHeight(val)
		end
	end,
	get = function(info) return P.iconSize end
}

defaultSettings.profile.insideRingColour	= {r=0, g=1, b=0} --green, 15% alpha
CoreOptionsTable.args.core.args.insideRingColour = {
	name = L["Inside range colour"],	order	= 18,
	desc = L["Colour of the ring when you're inside."],
	type = "color",
	hasAlpha	= false,
	set = function(info,r,g,b,a) 
		P.insideRingColour.r = r
		P.insideRingColour.g = g
		P.insideRingColour.b = b
--~ 		P.insideRingColour.a = a
	end,
	get = function(info) return P.insideRingColour.r, P.insideRingColour.g, P.insideRingColour.b, P.insideRingColour.a end --
}


defaultSettings.profile.outsideRingColour	= {r=1, g=0, b=0} --red 
CoreOptionsTable.args.core.args.outsideRingColour = {
	name = L["Outside range colour"],	order	= 20,
	desc = L["Colour of the ring when you're outside."],
	type = "color",
	hasAlpha	= false,
	set = function(info,r,g,b,a) 
		P.outsideRingColour.r = r
		P.outsideRingColour.g = g
		P.outsideRingColour.b = b
--~ 		P.outsideRingColour.a = a
		
	end,
	get = function(info) return P.outsideRingColour.r, P.outsideRingColour.g, P.outsideRingColour.b, P.outsideRingColour.a end
}

defaultSettings.profile.insideRingAlpha = 0.15 -- 15%
CoreOptionsTable.args.core.args.insideRingAlpha = {
	type	= "range",	order	= 21,
	name = L["Inside ring transparency"],
	desc = L["When inside, change ring transparency."],
	min		= 0,
	max		= 1,
	step	= 0.05,
	isPercent	= true,
	set = function(info,val) 
		P.insideRingAlpha = val;
	end,
	get = function(info) return P.insideRingAlpha end
}

defaultSettings.profile.outsideRingAlpha = 1 -- 100%
CoreOptionsTable.args.core.args.outsideRingAlpha = {
	type	= "range",	order	= 22,
	name = L["Outside ring transparency"],
	desc = L["When outside, change ring transparency."],
	min		= 0,
	max		= 1,
	step	= 0.05,
	isPercent	= true,
	set = function(info,val) 
		P.outsideRingAlpha = val;
	end,
	get = function(info) return P.outsideRingAlpha end
}
	
	


--AVR options
defaultSettings.profile.AVRdisplay = true
defaultSettings.profile.AVRLineThickness = 5
defaultSettings.profile.AVRSolidCircle = false
defaultSettings.profile.AVRTotemLocation = false
defaultSettings.profile.avrShowRange = 50 --at 100y our totems disapear.
defaultSettings.profile.AVRTotemColourRing = false
defaultSettings.profile.avrInsideRingAlpha = 0.15
defaultSettings.profile.avrOutsideRingAlpha = 1
defaultSettings.profile.avrFireNovaRing = true
defaultSettings.profile.avrFireNovaColour	= {r=1, g=1, b=0} --yellow
defaultSettings.profile.avrColourRingBySchool = true

function AddAVROptions()
	CoreOptionsTable.args.avr = { --reset
		name = L["AVR"],
		type = "group",
		order = 3,
		args={}
	}
	
	
	
	CoreOptionsTable.args.avr.args.AVRdisplay = {
		type = "toggle",	order	= 1,
		name	= L["AVR Rings"],
		desc	= L["If Augmented Virtual Reality is running, Add totem rings to 3D world."],
		set = function(info,val) 
			P.AVRdisplay = val
			
			if val == false then
				for totemGUID in pairs(totemMeshes) do 
					RemoveTotemFromAVR(totemGUID)
				end
			end
		end,
		get = function(info) return P.AVRdisplay end
	}
	

	CoreOptionsTable.args.avr.args.AVRLineThickness = {
		type	= "range",	order	= 2,
		name = L["Thickness"],
		desc = L["Thickness of the ring lines. Redrop totem to see change."],
		min		= 1,
		max		= 10,
		step	= 1,
		set = function(info,val) 
			P.AVRLineThickness = val;
		end,
		get = function(info) return P.AVRLineThickness end
	}
	
--~ 	CoreOptionsTable.args.avr.args.AVRSolidCircle = {
--~ 		type = "toggle",	order	= 3,
--~ 		name	= L["Solid Circle"],
--~ 		desc	= L["Colour the circle. Redrop totem to see change."],
--~ 		set = function(info,val) 
--~ 			P.AVRSolidCircle = val
--~ 			
--~ 		end,
--~ 		get = function(info) return P.AVRSolidCircle end
--~ 	}
	
	CoreOptionsTable.args.avr.args.AVRTotemLocation = {
		type = "toggle",	order	= 4,
		name	= L["Totem location hexagon"],
		desc	= L["Add a small hexagon under the totem.\nThis is where we think the totem dropped."],
		set = function(info,val) 
			P.AVRTotemLocation = val
			
		end,
		get = function(info) return P.AVRTotemLocation end
	}
	
	
	
	CoreOptionsTable.args.avr.args.avrShowRange = {
		type	= "range",	order	= 5,
		name = L["Show Range"],
		desc = L["Show AVR rings if you're within x yards."],
		min		= 30,
		max		= 100,
		step	= 5,
		set = function(info,val) 
			P.avrShowRange = val;
		end,
		get = function(info) return P.avrShowRange end
	}
	
	
	CoreOptionsTable.args.avr.args.AVRTotemColourRing = {
		type = "toggle",	order	= 6,
		name	= L["Extra school colour Ring"],
		desc	= L["Show a extra ring coloured by school. This is useful if you want a ring for range and school."],
		set = function(info,val) 
			P.AVRTotemColourRing = val
			
		end,
		get = function(info) return P.AVRTotemColourRing end
	}
	
	

	CoreOptionsTable.args.avr.args.avrInsideRingAlpha = {
		type	= "range",	order	= 7,
		name = L["Inside ring transparency"],
		desc = L["When inside, change ring transparency."],
		min		= 0,
		max		= 1,
		step	= 0.05,
		isPercent	= true,
		set = function(info,val) 
			P.avrInsideRingAlpha = val;
		end,
		get = function(info) return P.avrInsideRingAlpha end
	}
	
	CoreOptionsTable.args.avr.args.avrOutsideRingAlpha = {
		type	= "range",	order	= 8,
		name = L["Outside ring transparency"],
		desc = L["When outside, change ring transparency."],
		min		= 0,
		max		= 1,
		step	= 0.05,
		isPercent	= true,
		set = function(info,val) 
			P.avrOutsideRingAlpha = val;
		end,
		get = function(info) return P.avrOutsideRingAlpha end
	}
	
	
	CoreOptionsTable.args.avr.args.avrFireNovaRing = {
		type = "toggle",	order	= 9,
		name	= L["Fire Nova ring"],
		desc	= L["Show a extra ring around fire totem where fire nova will hit."],
		set = function(info,val) 
			P.avrFireNovaRing = val
			
		end,
		get = function(info) return P.avrFireNovaRing end
	}
	
	
	CoreOptionsTable.args.avr.args.avrFireNovaColour = {
		name = L["Fire Nova colour"],	order	= 10,
		desc = L["Colour of the Fire Nova ring"],
		type = "color",
--~ 		hasAlpha	= true,
		set = function(info,r,g,b,a) 
			P.avrFireNovaColour.r = r
			P.avrFireNovaColour.g = g
			P.avrFireNovaColour.b = b
--~ 			P.avrFireNovaColour.a = a
			
		end,
		get = function(info) return P.avrFireNovaColour.r, P.avrFireNovaColour.g, P.avrFireNovaColour.b, P.avrFireNovaColour.a end --
	}
	
	
	CoreOptionsTable.args.avr.args.avrColourRingBySchool = {
		type = "toggle",	order	= 4,
		name	= L["Colour ring by school"],
		desc	= L["Colour the AVR rings by totem school instead of range"],
		set = function(info,val) 
			P.avrColourRingBySchool = val
			
--~ 			if val == true then
--~ 				local totemSlot
--~ 				for totemGUID, data in pairs(activeTotems) do 
--~ 					totemSlot = data.totemSlot
--~ 					data.icon.outlineTexture:SetVertexColor(P.totemColour[totemSlot].r, P.totemColour[totemSlot].g, P.totemColour[totemSlot].b, P.totemColour[totemSlot].a)
--~ 				end
--~ 			end
			
		end,
		get = function(info) return P.avrColourRingBySchool end
	}

end






local table_sort = table.sort
local table_insert = table.insert
local table_getn = table.getn
--Totems page
function BuildPrefixUI()--	/script TR.BuildPrefixUI()
	CoreOptionsTable.args.totems = { --reset
		name = L["Totems"],
		type = "group",
		order = 2,
		args={}
	}
	
	
	local totems = {} --sortable list
	
	local totemName
	for spellID, data in pairs(core.totemInfo) do 
		totemName = data.name or GetSpellInfo(spellID)
		if table_getn(totems) == 0 then
			table_insert(totems, #totems+1, totemName)
		else
			for i=1, table_getn(totems) do 
				if totems[i] == totemName then
					break
				elseif i == table_getn(totems) then
					table_insert(totems, #totems+1, totemName)
				end
			end
		end
		
	end
	
	table_sort(totems, function(a,b) 
		if(a and b) then 
			return a < b
		end 
	end)
		--totemOpts
	for i=1, table_getn(totems) do 
		totemName = totems[i]
--~ 		Debug("BuildPrefixUI", i, totems[i])
		
		if P.totemOpts[totemName] == nil then
			P.totemOpts[totemName] = {shown = true} --show by default, using a table incase I need to add options later.
		end
		
		CoreOptionsTable.args.totems.args[totemName] = {
			type = "toggle",	order	= i,
			name = totemName,
			desc = L["Show %s on minimap."]:format(totemName),
			set = function(info,val) 
				local totemName = info[2]
				P.totemOpts[totemName].shown = val
				
				for totemGUID, data in pairs(activeTotems) do 
					if data.name == totemName then
						RemoveTotem(totemGUID)
					end
				end
			end,
			get = function(info) return P.totemOpts[info[2]] and P.totemOpts[info[2]].shown end
		}
		
		
	end
	
	
end
